//
//  TimingViewController.m
//  iOS Hotspot Cracker
//
//  Copyright (c) 2013, Andreas Kurtz & Markus Trossbach, Friedrich-Alexander-University, Erlangen, Germany.
//  All rights reserved.
//

#import "TimingViewController.h"
#import "PasswordViewController.h"
#import "WordlistGenerator.h"
#import "NoDataView.h"

@interface TimingViewController ()

@end

@implementation TimingViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.passwordText.delegate = self;
    self.noDataView = [[NoDataView alloc] initWithFrame:self.view.bounds];
    
	// Do any additional setup after loading the view.
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    if([[WordlistGenerator sharedInstance].sortedWordlist count] == 0) {
        [self.view addSubview:self.noDataView];
    } else {
        [self.noDataView removeFromSuperview];
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)tapDone:(id)sender {
    [self.passwordText resignFirstResponder];
}

- (IBAction)beginEditing:(id)sender {
    [self.navItem setRightBarButtonItem:self.doneButton animated:YES];
}

- (IBAction)endEditing:(id)sender {
    [self.navItem setRightBarButtonItem:nil animated:YES];
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [self tapCalc:nil];
    return YES;
}

- (IBAction)tapCalc:(id)sender {
    NSString* password = self.passwordText.text;
    
    NSString *regexStr = @"^([A-Za-z]+)([0-9]*)$";
    NSRegularExpression *regex = [NSRegularExpression regularExpressionWithPattern:regexStr options:0 error:nil];
    
    NSTextCheckingResult* result = [regex firstMatchInString:password options:0 range:NSMakeRange(0, [password length])];
    
    if(!result) {
        UIAlertView* alert = [[UIAlertView alloc] initWithTitle:@"Wrong password" message:@"The entered password does not match any pattern used by Apple to generate hotspot default passwords." delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
    } else {
        NSRange range1 = [result rangeAtIndex:1];
        NSRange range2 = [result rangeAtIndex:2];
        
        NSString* string1 = [password substringWithRange:range1];
        NSString* string2 = [password substringWithRange:range2];
    
        NSUInteger a = [[WordlistGenerator sharedInstance].sortedWordlist indexOfObject:string1];
        
        if(a == NSNotFound) {
            UIAlertView* alert = [[UIAlertView alloc] initWithTitle:@"Unknown password" message:@"The entered password was not found in the wordlist." delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
            [alert show];
        } else if([string2 length] > 4) {
            UIAlertView* alert = [[UIAlertView alloc] initWithTitle:@"Wrong password" message:@"The entered password does not match any pattern used by Apple to generate hotspot default passwords." delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
            [alert show];
        } else {
            [self.passwordText resignFirstResponder];
            PasswordViewController* vc = [self.storyboard instantiateViewControllerWithIdentifier:@"PasswordViewController"];
            vc.password = password;
            vc.passwordPosition = a;
            vc.passwordNumbers = [string2 integerValue];
            vc.passwordNumbersEntered = [string2 length] != 0;
            [self.navigationController pushViewController:vc animated:YES];
        }
        
        
    }
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if([segue.identifier isEqualToString:@"SEGUE_PASSWORD"]) {
        PasswordViewController* vc = segue.destinationViewController;
    
        vc.password = self.passwordText.text;
    }
}
@end
